# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import account_move
from . import mrp_production
from . import sale_order
from . import sale_order_line
from . import stock_move
